<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserAddress;
use App\Models\Order;
use Illuminate\Support\Facades\Input;
use Validator;
use Session;
use Illuminate\Support\Str;
use Auth;
class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {

        $this->middleware('auth');
        $this->middleware(function ($request, $next) {      
            if(auth()->user()->caterer_id!=''){
                Session::flash('message', 'You are not autherized to access this.');
                return redirect('admin/home');
            }
            return $next($request);
        });
    }
    public function index()
    {
        //
        $data = User::where('is_admin','0')->get();
        return view('customers.index',get_defined_vars());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        return view('customers.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //validation
        $rules = array(
            'title'       => 'required|unique:users',
            'arabic_title'       => 'required|unique:users',
            'arabic_description'       => 'required',
            'description'       => 'required'
        );
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect('admin/customers/create')
                ->withErrors($validator);
        }else{
            // store
            $Page = new Page;
            $Page->title = $request->get('title');
            $Page->slug = Str::slug($request->get('title'));
            $Page->arabic_title = $request->get('arabic_title');
            $Page->description = $request->get('description');
            $Page->arabic_description = $request->get('arabic_description');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/pages');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //get record
        $data = Page::find($id);
        return view('pages.edit',get_defined_vars());
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //update the record
        $Page = Page::find($id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                $res['status'] = "201";
                $res['msg'] = "Image format must be jpeg,jpg,png";
                return json_encode($res);
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/page_image/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $Page->image;
        }
            
            $Page->title = $request->get('title');
            $Page->slug = Str::slug($request->get('title'));
            $Page->arabic_title = $request->get('arabic_title');
            $Page->description = $request->get('description');
            $Page->arabic_description = $request->get('arabic_description');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/customers');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //delete record
        $data = User::find($id);
        $data->delete(); 
        Session::flash('message', 'Record has been deleted successfully!');
        return redirect('admin/customers');
    }

    //Update record Status START
    public function status($id){
        $data = User::where('id',$id)->first();
        if($data->status=='1'){
            User::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            User::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        Session::flash('message', 'Status has been updated successfully!');
            return redirect('admin/customers');
    }
    //Update record Status START

    //Get user addresses START
    public function customer_addresses($id)
    {
        //
        $data = UserAddress::where('user_id',$id)->get();
        $user = User::find($id);
        return view('customers.customer_addresses',get_defined_vars());
    }
    //Get user addresses END

    //Get user addresses START
    public function customer_orders($id)
    {
        //
        $data = Order::where('customer_id',$id)->get();
        $user = User::find($id);
        return view('customers.customer_orders',get_defined_vars());
    }
    //Get user addresses END
}
