<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Currency;
use App\Models\Category;
use App\Models\SubCategory;
use App\Models\MasterItem;
use Illuminate\Support\Facades\Input;
use Validator;
use Session;
use Auth;
class MasterItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {

        $this->middleware('auth');
        $this->middleware(function ($request, $next) {      
            if(auth()->user()->caterer_id!=''){
                Session::flash('message', 'You are not autherized to access this.');
                return redirect('admin/home');
            }
            return $next($request);
        });
    }
    public function index()
    {
        //
        $data = MasterItem::all();
        foreach($data as $k=>$datas){
            $currency_data=Currency::find($datas->currency_id);
            $data[$k]->currency = $currency_data->title;
        }
        return view('master_items.index',get_defined_vars());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //get category listing
        $categories = Currency::where('status','1')->get();
        $all_cats = Category::where('status','1')->get();

        return view('master_items.create',get_defined_vars());
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //validation
        $rules = array(
            'title'       => 'required|unique:master_items',
            'arabic_title' => 'required|unique:master_items',
            'description' => 'required',
            'arabic_description' => 'required',
            'price' => 'required',
            'image' => 'required',
        );
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect('admin/master_items/create')
                ->withErrors($validator);
        }else{
            // store
            if ($file = $request->hasFile('image')) {
                $file = $request->file('image');
                $imageType = $file->getClientmimeType();
                // print_r($imageType); die;
                $rules = array(
                    'image' => 'mimes:jpeg,jpg,png',
                );

                $validator = Validator::make($request->all(), $rules);

                if ($validator->fails()) {
                    $res['status'] = "201";
                    $res['msg'] = "Image format must be jpeg,jpg,png";
                    return json_encode($res);
                } else {
                    $fileName = $file->getClientOriginalName();
                    $fileNameUnique = time() . '_' . $fileName;
                    $destinationPath = public_path() . '/master_items/';
                    $file->move($destinationPath, $fileNameUnique);
                }
                $imageData = $fileNameUnique;
            } else {
                $imageData = '';
            }
            $Category = new MasterItem;
            $Category->category_id = $request->get('category_id');
            $Category->sub_category_id = $request->get('sub_category_id');           
            $Category->title = $request->get('title');
            $Category->description = $request->get('description');
            $Category->arabic_title = $request->get('arabic_title');
            $Category->arabic_description = $request->get('arabic_description');
            $Category->price = $request->get('price');
            $Category->currency_id = $request->get('currency_id');
            $Category->image = $imageData;
            $Category->status = $request->get('status');
            $Category->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/master_items');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //get record
        $data = MasterItem::find($id);
        $categories = Currency::where('status','1')->get();
        return view('master_items.edit',get_defined_vars());
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //update the record
        $Category = MasterItem::find($id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                $res['status'] = "201";
                $res['msg'] = "Image format must be jpeg,jpg,png";
                return json_encode($res);
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/master_items/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $Category->image;
        }
            
            $Category->title = $request->get('title');
            $Category->arabic_title = $request->get('arabic_title');
            $Category->description = $request->get('description');
            $Category->arabic_description = $request->get('arabic_description');
            $Category->price = $request->get('price');
            $Category->currency_id = $request->get('currency_id');
            $Category->status = $request->get('status');
            $Category->image = $imageData;
            $Category->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/master_items');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //delete record
        $data = MasterItem::find($id);
        $data->delete(); 
        Session::flash('message', 'Record has been deleted successfully!');
        return redirect('admin/master_items');
    }

    //Update City Status START
    public function status($id){
        $city = MasterItem::where('id',$id)->first();
        if($city->status=='1'){
            MasterItem::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            MasterItem::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        Session::flash('message', 'Status has been updated successfully!');
            return redirect('admin/master_items');
    }
    //Update City Status START

    //Get Sub Category as per the cat START
    public function getSub(Request $request){
        $data['sub_cats'] = SubCategory::where("category_id",$request->category_id)
                    ->get(["title","id"]);
        return response()->json($data);
    }
    //Get Sub Category as per the cat START
}
