<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Offer;
use Illuminate\Support\Facades\Input;
use Validator;
use Session;
use Illuminate\Support\Str;
use Auth;
class OfferController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {

        $this->middleware('auth');
        $this->middleware(function ($request, $next) {      
            if(auth()->user()->caterer_id!=''){
                Session::flash('message', 'You are not autherized to access this.');
                return redirect('admin/home');
            }
            return $next($request);
        });
    }
    public function index()
    {
        //
        $data = Offer::all();
        return view('offers.index',get_defined_vars());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //get 
        
        return view('offers.create',get_defined_vars());
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //validation
        $rules = array(
            'title'       => 'required|unique:offers',
            'arabic_title'       => 'required|unique:offers',
            'amount'       => 'required',
            'status'       => 'required',
            'type'       => 'required',
            'image'       => 'required'
        );
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect('admin/offers/create')
                ->withErrors($validator);
        }else{
            // store
            if ($file = $request->hasFile('image')) {
                $file = $request->file('image');
                $imageType = $file->getClientmimeType();
                // print_r($imageType); die;
                $rules = array(
                    'image' => 'mimes:jpeg,jpg,png',
                );

                $validator = Validator::make($request->all(), $rules);

                if ($validator->fails()) {
                    $res['status'] = "201";
                    $res['msg'] = "Image format must be jpeg,jpg,png";
                    return json_encode($res);
                } else {
                    $fileName = $file->getClientOriginalName();
                    $fileNameUnique = time() . '_' . $fileName;
                    $destinationPath = public_path() . '/offer_image/';
                    $file->move($destinationPath, $fileNameUnique);
                }
                $imageData = $fileNameUnique;
            } else {
                $imageData = '';
            }
            $Page = new Offer;
            $Page->title = $request->get('title');
            $Page->amount = Str::slug($request->get('amount'));
            $Page->arabic_title = $request->get('arabic_title');
            $Page->type = $request->get('type');
            $Page->status = $request->get('status');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/offers');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //get record
        $data = Offer::find($id);
        //get 
        
        return view('offers.edit',get_defined_vars());
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //update the record
        $Page = Offer::find($id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                $res['status'] = "201";
                $res['msg'] = "Image format must be jpeg,jpg,png";
                return json_encode($res);
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/offer_image/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $Page->image;
        }
            
            $Page->title = $request->get('title');
            $Page->arabic_title = $request->get('arabic_title');
            $Page->type = $request->get('type');
            $Page->amount = $request->get('amount');
            $Page->status = $request->get('status');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/offers');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //delete record
        $data = Offer::find($id);
        $data->delete(); 
        Session::flash('message', 'Record has been deleted successfully!');
        return redirect('admin/offers');
    }

    //Update record Status START
    public function status($id){
        $data = Offer::where('id',$id)->first();
        if($data->status=='1'){
            Offer::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Offer::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        Session::flash('message', 'Status has been updated successfully!');
            return redirect('admin/offers');
    }
    //Update record Status START
}
