<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\SubCategory;
use Illuminate\Support\Facades\Input;
use Validator;
use Session;
use Auth;
class SubCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {

        $this->middleware('auth');
        $this->middleware(function ($request, $next) {      
            if(auth()->user()->caterer_id!=''){
                Session::flash('message', 'You are not autherized to access this.');
                return redirect('admin/home');
            }
            return $next($request);
        });
    }
    public function index()
    {
        //
        $data = SubCategory::all();
        foreach($data as $k=>$datas){
            $cat_data=Category::find($datas->category_id);
            $data[$k]->cat_name = $cat_data->title;
        }
        return view('sub_categories.index',get_defined_vars());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //get category listing
        $categories = Category::where('status','1')->get();
        return view('sub_categories.create',get_defined_vars());
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //validation
        $rules = array(
            'title'       => 'required|unique:sub_categories',
            'arabic_title' => 'required|unique:sub_categories'
        );
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect('admin/sub_categories/create')
                ->withErrors($validator);
        }else{
            // store
            if ($file = $request->hasFile('image')) {
                $file = $request->file('image');
                $imageType = $file->getClientmimeType();
                // print_r($imageType); die;
                $rules = array(
                    'image' => 'mimes:jpeg,jpg,png',
                );

                $validator = Validator::make($request->all(), $rules);

                if ($validator->fails()) {
                    $res['status'] = "201";
                    $res['msg'] = "Image format must be jpeg,jpg,png";
                    return json_encode($res);
                } else {
                    $fileName = $file->getClientOriginalName();
                    $fileNameUnique = time() . '_' . $fileName;
                    $destinationPath = public_path() . '/sub_categories_images/';
                    $file->move($destinationPath, $fileNameUnique);
                }
                $imageData = $fileNameUnique;
            } else {
                $imageData = '';
            }
            $Category = new SubCategory;
            $Category->category_id = $request->get('category_id');
            $Category->title = $request->get('title');
            $Category->arabic_title = $request->get('arabic_title');
            $Category->status = $request->get('status');
            $Category->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/sub_categories');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //get record
        $data = SubCategory::find($id);
        $categories = Category::where('status','1')->get();
        return view('sub_categories.edit',get_defined_vars());
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //update the record
        $Category = SubCategory::find($id);
        // if ($file = $request->hasFile('image')) {
        //     $file = $request->file('image');
        //     $imageType = $file->getClientmimeType();
        //     // print_r($imageType); die;
        //     $rules = array(
        //         'image' => 'mimes:jpeg,jpg,png',
        //     );

        //     $validator = Validator::make($request->all(), $rules);

        //     if ($validator->fails()) {
        //         $res['status'] = "201";
        //         $res['msg'] = "Image format must be jpeg,jpg,png";
        //         return json_encode($res);
        //     } else {
        //         $fileName = $file->getClientOriginalName();
        //         $fileNameUnique = time() . '_' . $fileName;
        //         $destinationPath = public_path() . '/sub_categories_images/';
        //         $file->move($destinationPath, $fileNameUnique);
        //     }
        //     $imageData = $fileNameUnique;
        // } else {
        //     $imageData = $Category->image;
        // }
            
            $Category->title = $request->get('title');
            $Category->arabic_title = $request->get('arabic_title');
            $Category->status = $request->get('status');
            $Category->save();

            // redirect
            Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/sub_categories');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //delete record
        $data = SubCategory::find($id);
        $data->delete(); 
        Session::flash('message', 'Record has been deleted successfully!');
        return redirect('admin/sub_categories');
    }

    //Update City Status START
    public function status($id){
        $city = SubCategory::where('id',$id)->first();
        if($city->status=='1'){
            SubCategory::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            SubCategory::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        Session::flash('message', 'Status has been updated successfully!');
            return redirect('admin/sub_categories');
    }
    //Update City Status START
}
